from fake import Factory, Faker

from data import FIRST_NAMES, LAST_NAMES, WORDS

__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
__copyright__ = "2023-2024 Artur Barseghyan"
__license__ = "MIT"
__all__ = (
    "FACTORY",
    "FAKER",
)


class FakerOverrideDefaultData(Faker):
    """Faker class for custom names and words."""

    def load_names(self) -> None:
        """Override default first- and last-names dictionaries."""
        self._first_names = FIRST_NAMES
        self._last_names = LAST_NAMES

    def load_words(self) -> None:
        """Override default words dictionary."""
        self._words = WORDS


FAKER = FakerOverrideDefaultData(alias="override_default_data")
FACTORY = Factory(FAKER)



import unittest
from datetime import datetime

from fake import FILE_REGISTRY, xor_transform

from article.factories import ArticleFactory, UserFactory
from article.models import Article, User

__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
__copyright__ = "2023-2024 Artur Barseghyan"
__license__ = "MIT"
__all__ = ("FactoriesTestCase",)


class FactoriesTestCase(unittest.TestCase):
    def tearDown(self):
        FILE_REGISTRY.clean_up()

    def test_sub_factory(self) -> None:
        article = ArticleFactory()

        # Testing SubFactory
        self.assertIsInstance(article.author, User)
        self.assertIsInstance(article.author.id, int)
        self.assertIsInstance(article.author.is_staff, bool)
        self.assertIsInstance(article.author.date_joined, datetime)

        # Testing Factory
        self.assertIsInstance(article.id, int)
        self.assertIsInstance(article.slug, str)

        # Testing hooks
        self.assertTrue(
            hasattr(article, "_pre_save_called") and article._pre_save_called
        )
        self.assertTrue(
            hasattr(article, "_post_save_called") and article._post_save_called
        )
        self.assertTrue(
            hasattr(article.author, "_pre_save_called")
            and article.author._pre_save_called
        )
        self.assertTrue(
            hasattr(article.author, "_post_save_called")
            and article.author._post_save_called
        )

        # Testing batch creation
        articles = ArticleFactory.create_batch(5)
        self.assertEqual(len(articles), 5)
        self.assertIsInstance(articles[0], Article)

    def test_pre_save_and_post_save(self) -> None:
        """Test PreSave and PostSave."""
        user = UserFactory(is_staff=True)
        self.assertEqual(
            xor_transform(user.password),
            "test1234",
        )
        self.assertEqual(list(user.groups)[0].name, "TestGroup1234")



#!/usr/bin/env python
import argparse
import os
import sys
import unittest

import IPython


def run_tests():
    """Function to run tests in the customization directory."""
    loader = unittest.TestLoader()
    suite = loader.discover(start_dir="./", pattern="tests.py")
    runner = unittest.TextTestRunner()
    runner.run(suite)


def main():
    """Run administrative tasks based on command line arguments."""
    sys.path.insert(0, os.path.abspath(os.path.join("..", "..")))
    sys.path.insert(0, os.path.abspath("."))
    parser = argparse.ArgumentParser(
        description="Management script for the project."
    )
    parser.add_argument("command", help="The command to run (test or shell)")

    args = parser.parse_args()

    if args.command == "test":
        run_tests()
    elif args.command == "shell":
        IPython.embed()
    else:
        print("Unknown command. Use 'test' or 'shell'.")


if __name__ == "__main__":
    main()



from datetime import date

from fake import xor_transform
from tortoise import fields
from tortoise.models import Model

__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
__copyright__ = "2023-2024 Artur Barseghyan"
__license__ = "MIT"
__all__ = (
    "Article",
    "Group",
    "User",
)


class Group(Model):
    """Group model."""

    id = fields.IntField(pk=True)
    name = fields.CharField(max_length=255, unique=True)

    def __str__(self):
        return self.name


class User(Model):
    """User model."""

    id = fields.IntField(pk=True)
    username = fields.CharField(max_length=255, unique=True)
    first_name = fields.CharField(max_length=255)
    last_name = fields.CharField(max_length=255)
    email = fields.CharField(max_length=255)
    password = fields.CharField(max_length=255, null=True, blank=True)
    last_login = fields.DatetimeField(null=True, blank=True)
    is_superuser = fields.BooleanField(default=False)
    is_staff = fields.BooleanField(default=False)
    is_active = fields.BooleanField(default=True)
    date_joined = fields.DatetimeField(null=True, blank=True)
    groups = fields.ManyToManyField("models.Group", on_delete=fields.CASCADE)

    def __str__(self):
        return self.title

    def set_password(self, password: str) -> None:
        self.password = xor_transform(password)


class Article(Model):
    """Article model."""

    id = fields.IntField(pk=True)
    title = fields.CharField(max_length=255)
    slug = fields.CharField(max_length=255, unique=True)
    content = fields.TextField()
    headline = fields.TextField()
    category = fields.CharField(max_length=255)
    pages = fields.IntField()
    auto_minutes_to_read = fields.IntField()
    image = fields.TextField(null=True, blank=True)
    pub_date = fields.DateField(default=date.today)
    safe_for_work = fields.BooleanField(default=False)
    minutes_to_read = fields.IntField(default=5)
    author = fields.ForeignKeyField(
        "models.User",
        on_delete=fields.CASCADE,
    )
    tags = fields.JSONField(default=list)

    def __str__(self):
        return self.title



from django.conf import settings
from fake import FAKER, FileSystemStorage, TextPdfGenerator

STORAGE = FileSystemStorage(root_path=settings.MEDIA_ROOT, rel_path="tmp")

pdf_file = FAKER.pdf_file(generator=TextPdfGenerator, storage=STORAGE)



import string
import unittest
from decimal import Decimal

from fake import FAKER, FILE_REGISTRY, StringValue, slugify
from hypothesis import Verbosity, given, settings
from hypothesis import strategies as st

__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
__copyright__ = "2023-2024 Artur Barseghyan"
__license__ = "MIT"
__all__ = ("TestFakerWithHypothesis",)

# Enable verbose logging for all tests in the class
settings.register_profile("debug", verbosity=Verbosity.verbose)
settings.load_profile("debug")


class TestFakerWithHypothesis(unittest.TestCase):
    """Test `fake.Faker` with hypothesis."""

    def setUp(self) -> None:
        self.faker = FAKER

    def tearDown(self) -> None:
        FILE_REGISTRY.clean_up()

    @given(st.text(min_size=5))
    def test_slugify(self, value):
        result = slugify(f"{value}a1")

        # Check that the result is lowercased
        self.assertEqual(result, result.lower())

        # Check that the result does not contain any punctuation or whitespace
        for char in string.punctuation + string.whitespace:
            self.assertNotIn(char, result)

        # Check that the result is an alpha-numeric string (since all
        # punctuations and whitespaces are removed)
        self.assertTrue(result.isalnum())

    @given(nb=st.integers(min_value=1, max_value=10))
    def test_words(self, nb):
        words = self.faker.words(nb=nb)
        self.assertIsInstance(words, list)
        self.assertEqual(len(words), nb)

    @given(nb_words=st.integers(min_value=1, max_value=10))
    def test_sentence(self, nb_words):
        sentence = self.faker.sentence(nb_words=nb_words)
        self.assertIsInstance(sentence, str)
        self.assertTrue(len(sentence.split()) == nb_words)

    @given(nb=st.integers(min_value=1, max_value=10))
    def test_sentences(self, nb):
        sentences = self.faker.sentences(nb=nb)
        self.assertIsInstance(sentences, list)
        self.assertEqual(len(sentences), nb)

    @given(nb_sentences=st.integers(min_value=1, max_value=10))
    def test_paragraph(self, nb_sentences):
        paragraph = self.faker.paragraph(nb_sentences=nb_sentences)
        self.assertIsInstance(paragraph, str)

    @given(nb=st.integers(min_value=1, max_value=10))
    def test_paragraphs(self, nb):
        paragraphs = self.faker.paragraphs(nb=nb)
        self.assertIsInstance(paragraphs, list)
        self.assertEqual(len(paragraphs), nb)

    @given(nb_chars=st.integers(min_value=1, max_value=1000))
    def test_text(self, nb_chars):
        text = self.faker.text(nb_chars=nb_chars)
        self.assertIsInstance(text, str)
        self.assertTrue(len(text) <= nb_chars)

    @given(nb=st.integers(min_value=1, max_value=10))
    def test_texts(self, nb):
        texts = self.faker.texts(nb=nb)
        self.assertIsInstance(texts, list)
        self.assertEqual(len(texts), nb)

    @given(
        min_val=st.floats(
            min_value=-1e10,
            max_value=1e10,
            allow_nan=False,
            allow_infinity=False,
        ),
        max_val=st.floats(
            min_value=-1e10,
            max_value=1e10,
            allow_nan=False,
            allow_infinity=False,
        ),
    )
    def test_pyfloat(self, min_val, max_val):
        if min_val > max_val:
            min_val, max_val = max_val, min_val
        val = self.faker.pyfloat(min_value=min_val, max_value=max_val)
        self.assertIsInstance(val, float)
        self.assertGreaterEqual(val, min_val)
        self.assertLessEqual(val, max_val)

    @given(
        left_digits=st.integers(min_value=0, max_value=10),
        right_digits=st.integers(min_value=0, max_value=10),
        positive=st.booleans(),
    )
    def test_pydecimal(self, left_digits, right_digits, positive):
        decimal_number = self.faker.pydecimal(
            left_digits=left_digits,
            right_digits=right_digits,
            positive=positive,
        )
        self.assertIsInstance(decimal_number, Decimal)

    @given(nb_pages=st.integers(min_value=1, max_value=10))
    def test_pdf(self, nb_pages):
        pdf_bytes = self.faker.pdf(nb_pages=nb_pages)
        self.assertIsInstance(pdf_bytes, bytes)

    @given(
        size=st.tuples(
            st.integers(min_value=1, max_value=500),
            st.integers(min_value=1, max_value=500),
        ),
        color=st.tuples(
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
        ),
    )
    def test_png(self, size, color):
        png_bytes = self.faker.png(size=size, color=color)
        self.assertIsInstance(png_bytes, bytes)

    @given(
        size=st.tuples(
            st.integers(min_value=1, max_value=500),
            st.integers(min_value=1, max_value=500),
        ),
        color=st.tuples(
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
        ),
    )
    def test_svg(self, size, color):
        svg_bytes = self.faker.svg(size=size, color=color)
        self.assertIsInstance(svg_bytes, bytes)

    @given(
        size=st.tuples(
            st.integers(min_value=1, max_value=500),
            st.integers(min_value=1, max_value=500),
        ),
        color=st.tuples(
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
        ),
    )
    def test_bmp(self, size, color):
        bmp_bytes = self.faker.bmp(size=size, color=color)
        self.assertIsInstance(bmp_bytes, bytes)

    @given(
        size=st.tuples(
            st.integers(min_value=1, max_value=500),
            st.integers(min_value=1, max_value=500),
        ),
        color=st.tuples(
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
        ),
    )
    def test_gif(self, size, color):
        gif_bytes = self.faker.gif(size=size, color=color)
        self.assertIsInstance(gif_bytes, bytes)

    @given(nb_pages=st.integers(min_value=1, max_value=10))
    def test_docx(self, nb_pages):
        docx_bytes = self.faker.docx(nb_pages=nb_pages)
        self.assertIsInstance(docx_bytes, bytes)

    @given(nb_pages=st.integers(min_value=1, max_value=10))
    def test_pdf_file(self, nb_pages):
        pdf_file = self.faker.pdf_file(nb_pages=nb_pages)
        self.assertIsInstance(pdf_file, StringValue)

    @given(
        size=st.tuples(
            st.integers(min_value=1, max_value=500),
            st.integers(min_value=1, max_value=500),
        ),
        color=st.tuples(
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
        ),
    )
    def test_png_file(self, size, color):
        png_file = self.faker.png_file(size=size, color=color)
        self.assertIsInstance(png_file, StringValue)

    @given(
        size=st.tuples(
            st.integers(min_value=1, max_value=500),
            st.integers(min_value=1, max_value=500),
        ),
        color=st.tuples(
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
        ),
    )
    def test_svg_file(self, size, color):
        svg_file = self.faker.svg_file(size=size, color=color)
        self.assertIsInstance(svg_file, StringValue)

    @given(
        size=st.tuples(
            st.integers(min_value=1, max_value=500),
            st.integers(min_value=1, max_value=500),
        ),
        color=st.tuples(
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
        ),
    )
    def test_bmp_file(self, size, color):
        bmp_file = self.faker.bmp_file(size=size, color=color)
        self.assertIsInstance(bmp_file, StringValue)

    @given(
        size=st.tuples(
            st.integers(min_value=1, max_value=500),
            st.integers(min_value=1, max_value=500),
        ),
        color=st.tuples(
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
            st.integers(min_value=0, max_value=255),
        ),
    )
    def test_gif_file(self, size, color):
        gif_file = self.faker.gif_file(size=size, color=color)
        self.assertIsInstance(gif_file, StringValue)

    @given(nb_pages=st.integers(min_value=1, max_value=10))
    def test_docx_file(self, nb_pages):
        docx_file = self.faker.docx_file(nb_pages=nb_pages)
        self.assertIsInstance(docx_file, StringValue)

    @given(nb_chars=st.integers(min_value=1, max_value=1000))
    def test_txt_file(self, nb_chars):
        txt_file = self.faker.txt_file(nb_chars=nb_chars)
        self.assertIsInstance(txt_file, StringValue)


if __name__ == "__main__":
    unittest.main()



import random
from datetime import datetime
from functools import partial
from pathlib import Path

from fake import (
    FACTORY,
    FileSystemStorage,
    LazyAttribute,
    LazyFunction,
    ModelFactory,
    SubFactory,
    post_save,
    pre_save,
    trait,
)

from article.models import Article, User

__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
__copyright__ = "2023-2024 Artur Barseghyan"
__license__ = "MIT"
__all__ = (
    "ArticleFactory",
    "UserFactory",
)

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent
MEDIA_ROOT = BASE_DIR / "media"

STORAGE = FileSystemStorage(root_path=MEDIA_ROOT, rel_path="tmp")
CATEGORIES = (
    "art",
    "technology",
    "literature",
)


class UserFactory(ModelFactory):
    id = FACTORY.pyint()  # type: ignore
    username = FACTORY.username()  # type: ignore
    first_name = FACTORY.first_name()  # type: ignore
    last_name = FACTORY.last_name()  # type: ignore
    email = LazyAttribute(lambda o: f"{o.username}@example.com")
    last_login = FACTORY.date_time()  # type: ignore
    is_superuser = False
    is_staff = False
    is_active = FACTORY.pybool()  # type: ignore
    date_joined = LazyFunction(datetime.now)

    class Meta:
        model = User

    @trait
    def is_admin_user(self, instance: User) -> None:
        instance.is_superuser = True
        instance.is_staff = True
        instance.is_active = True

    @pre_save
    def _pre_save_method(self, instance):
        instance._pre_save_called = True

    @post_save
    def _post_save_method(self, instance):
        instance._post_save_called = True


class ArticleFactory(ModelFactory):
    id = FACTORY.pyint()  # type: ignore
    title = FACTORY.sentence()  # type: ignore
    slug = FACTORY.slug()  # type: ignore
    content = FACTORY.text()  # type: ignore
    headline = LazyAttribute(lambda o: o.content[:25])
    category = LazyFunction(partial(random.choice, CATEGORIES))
    image = FACTORY.png_file(storage=STORAGE)  # type: ignore
    pub_date = FACTORY.date()  # type: ignore
    safe_for_work = FACTORY.pybool()  # type: ignore
    minutes_to_read = FACTORY.pyint(min_value=1, max_value=10)  # type: ignore
    author = SubFactory(UserFactory)

    class Meta:
        model = Article

    @pre_save
    def _pre_save_method(self, instance):
        instance._pre_save_called = True

    @post_save
    def _post_save_method(self, instance):
        instance._post_save_called = True
